==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/xtjoinHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "Qƃt@C̍ڌ"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define TKYT "̓f[^̓˂킹鍀ږXg"
#define TKYC "Ŏw肵̓f[^̍ڂ-KŎw肳ꂽQƃf[^̍ڂs̍ڌs"

/*-K*/
#define MKYT "Qƃf[^̓˂킹鍀ږrXg"
#define MKYC "Ŏw肵Qƃf[^̍ڂ-kŎw肳ꂽ̓f[^̍ڂs̍ڌs"

/*-m*/
#define MSTT "Qƃt@C"
#define MSTC "Qƃt@Cw肷"

/*-f*/
#define FLDT "ږXg"
#define FLDC "Qƃt@C̍ږXg"
#define FLDF NULL

/*-n*/
#define TNLT "̓f[^o"
#define TNLC "Qƃf[^ɂȂ̓f[^NULLlƂďo͂tO"

/*-N*/
#define MNLT "Qƃf[^o"
#define MNLC "̓f[^ɂȂQƃf[^NULLlƂďo͂tO"

/*-H*/
#define HAST "hash"
#define HASC "̃IvVɂ苭IhashsB"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "-kŎw肵̓t@C̍ڒl-KŎw肵Qƃt@C̍ڒlrAlQƃt@C̍ڂB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtjoin -k ڋq -m ref.xt -f N, -i dat.xt -o rsl.xt\n\
xtjoin -k ڋq -m ref.xt -f N, -nN -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtnjoin,xtproduct,xtcommon"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4.tar.gz: musashi-core-1.0.4/help/ja-sjis/xtjoinHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "Qƃt@C̍ڌ"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define TKYT "̓f[^̓˂킹鍀ږXg"
#define TKYC "Ŏw肵̓f[^̍ڂ-KŎw肳ꂽQƃf[^̍ڂs̍ڌs"

/*-K*/
#define MKYT "Qƃf[^̓˂킹鍀ږrXg"
#define MKYC "Ŏw肵Qƃf[^̍ڂ-kŎw肳ꂽ̓f[^̍ڂs̍ڌs"

/*-m*/
#define MSTT "Qƃt@C"
#define MSTC "Qƃt@Cw肷"

/*-f*/
#define FLDT "ږXg"
#define FLDC "Qƃt@C̍ږXg"
#define FLDF NULL

/*-n*/
#define TNLT "̓f[^o"
#define TNLC "Qƃf[^ɂȂ̓f[^NULLlƂďo͂tO"

/*-N*/
#define MNLT "Qƃf[^o"
#define MNLC "̓f[^ɂȂQƃf[^NULLlƂďo͂tO"

/*-H*/
#define HAST "hash"
#define HASC "̃IvVɂ苭IhashsB"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "-kŎw肵̓t@C̍ڒl-KŎw肵Qƃt@C̍ڒlrAlQƃt@C̍ڂB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtjoin -k ڋq -m ref.xt -f N, -i dat.xt -o rsl.xt\n\
xtjoin -k ڋq -m ref.xt -f N, -nN -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtnjoin,xtproduct,xtcommon"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
